@@ -1,12 +1,12 @@
 #
-# $Id: Optimizer.pm,v 0.14 2004/11/05 12:44:32 dankogai Exp $
+# $Id: Optimizer.pm,v 0.16 2013/02/20 08:53:16 dankogai Exp dankogai $
 #
 package Regexp::Optimizer;
 use 5.006; # qr/(??{}/ needed
 use strict;
 use warnings;
 use base qw/Regexp::List/;
-our $VERSION = do { my @r = (q$Revision: 0.14 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 0.16 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 #our @EXPORT = qw();
 #our %EXPORT_TAGS = ( 'all' => [ qw() ] );
@@ -216,6 +216,10 @@ __END__
 
 Regexp::Optimizer - optimizes regular expressions
 
+=head1 OBSOLETED BY
+
+L<Regexp::Assemble>
+
 =head1 SYNOPSIS
 
   use Regexp::Optimizer;
@@ -240,14 +244,10 @@ To install this module type the following:
 
 Here is a quote from L<perltodo>.
 
-=over
+  Factoring out common suffices/prefices in regexps (trie optimization)
 
-Factoring out common suffices/prefices in regexps (trie optimization)
-
-Currently, the user has to optimize "foo|far" and "foo|goo" into
-"f(?:oo|ar)" and "[fg]oo" by hand; this could be done automatically.
-
-=back
+  Currently, the user has to optimize "foo|far" and "foo|goo" into
+  "f(?:oo|ar)" and "[fg]oo" by hand; this could be done automatically.
 
 This module implements just that.
 
@@ -338,7 +338,7 @@ tested very well.
 =item *
 
 Regex parser in this module (which itself is implemented by regular
-expression) is not as thoroughly tested as L<Regex::List>
+expression) is not as thoroughly tested as L<Regexp::List>
 
 =item *
 
